##  Step 6: (Optional) Request to Add IdP Connection to a Custom Subdomain
If your SAP LeanIX workspace uses a custom subdomain, the subdomain must be updated to include the new IdP connection. SAP LeanIX manages subdomains, so this process is not available through self-service. After a successful migration, submit a ticket to support. Provide the direct URLs of the relevant workspaces.
